| missPLS-package | R Documentation |
Methods-first tooling for reproducing and extending the partial least squares regression studies on incomplete data described in Nengsih et al. (2019) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1515/sagmb-2018-0059")}. The package provides simulation helpers, missingness generators, imputation wrappers, component-selection utilities, real-data diagnostics, and reproducible study orchestration for Nonlinear Iterative Partial Least Squares (NIPALS)-Partial Least Squares (PLS) workflows.
Maintainer: Frederic Bertrand frederic.bertrand@lecnam.net
Authors:
Titin Agustin Nengsih
Myriam Maumy-Bertrand
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.