View source: R/run_real_data_study.R
| run_real_data_study | R Documentation |
Run a real-data study
run_real_data_study(
dataset,
seed = NULL,
missing_props = seq(5, 50, 5),
mechanisms = c("MCAR", "MAR"),
reps = 1L,
baseline_reps = 100L,
max_ncomp = 12L,
criteria = c("Q2-LOO", "Q2-10fold", "AIC", "AIC-DoF", "BIC", "BIC-DoF"),
incomplete_methods = c("nipals_standard", "nipals_adaptative"),
imputation_methods = c("mice", "knn", "svd"),
folds = 10L,
mar_y_bias = 0.8
)
dataset |
A packaged dataset name or |
seed |
Optional base random seed. |
missing_props |
Missing-data proportions as fractions or percentages. |
mechanisms |
Missing-data mechanisms. |
reps |
Number of replicate missingness draws for each mechanism and proportion. |
baseline_reps |
Number of repeated complete-data |
max_ncomp |
Maximum number of extracted components. |
criteria |
Criteria evaluated on incomplete and imputed data. |
incomplete_methods |
Incomplete-data NIPALS workflows. |
imputation_methods |
Imputation methods. |
folds |
Number of folds used by |
mar_y_bias |
MAR bias parameter passed to |
A data frame with one row per study run.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.