View source: R/run_simulation_study.R
| run_simulation_study | R Documentation |
Run the simulation workflows used in the article and thesis.
run_simulation_study(
dimensions = list(c(500L, 100L), c(500L, 20L), c(100L, 20L), c(80L, 25L), c(60L, 33L),
c(40L, 50L), c(20L, 100L)),
true_ncomp = c(2L, 4L, 6L),
missing_props = seq(5, 50, 5),
mechanisms = c("MCAR", "MAR"),
reps = 1L,
seed = NULL,
max_ncomp = 8L,
criteria = c("Q2-LOO", "Q2-10fold", "AIC", "AIC-DoF", "BIC", "BIC-DoF"),
incomplete_methods = c("nipals_standard", "nipals_adaptative"),
imputation_methods = c("mice", "knn", "svd"),
folds = 10L,
mar_y_bias = 0.8
)
dimensions |
List of |
true_ncomp |
Vector of true component counts. |
missing_props |
Missing-data proportions as fractions or percentages. |
mechanisms |
Missing-data mechanisms. |
reps |
Number of replicates. |
seed |
Optional base random seed. |
max_ncomp |
Maximum number of extracted components. |
criteria |
Criteria evaluated on complete and imputed data. |
incomplete_methods |
Incomplete-data NIPALS workflows. |
imputation_methods |
Imputation methods. |
folds |
Number of folds used by |
mar_y_bias |
MAR bias parameter passed to |
A data frame with one row per study run.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.