Skip to contents

Bromhexine in pharmaceutical syrup used in the article and thesis.

Usage

bromhexine

Format

A misspls_dataset list with components:

name

Dataset name.

x

A numeric 23 x 64 predictor matrix.

y

A numeric response vector of length 23.

data

A data frame with response y and predictors x1 to x64.

source

A short source reference.

preprocessing

Dataset preprocessing notes.

notes

Additional study notes.

Goicoechea and Olivieri (1999a), calibration and test files bundled in extra_docs/pls_data.