| bromhexine | R Documentation |
Bromhexine in pharmaceutical syrup used in the article and thesis.
bromhexine
A misspls_dataset list with components:
Dataset name.
A numeric 23 x 64 predictor matrix.
A numeric response vector of length 23.
A data frame with response y and predictors x1 to x64.
A short source reference.
Dataset preprocessing notes.
Additional study notes.
Goicoechea and Olivieri (1999a), calibration and test files bundled in
extra_docs/pls_data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.