Skip to contents

Tetracycline in serum used in the article and thesis.

Usage

tetracycline

Format

A misspls_dataset list with components:

name

Dataset name.

x

A numeric 107 x 101 predictor matrix.

y

A numeric response vector of length 107.

data

A data frame with response y and predictors x1 to x101.

source

A short source reference.

preprocessing

Dataset preprocessing notes.

notes

Additional study notes.

Goicoechea and Olivieri (1999b), calibration and test files bundled in extra_docs/pls_data.