| tetracycline | R Documentation |
Tetracycline in serum used in the article and thesis.
tetracycline
A misspls_dataset list with components:
Dataset name.
A numeric 107 x 101 predictor matrix.
A numeric response vector of length 107.
A data frame with response y and predictors x1 to x101.
A short source reference.
Dataset preprocessing notes.
Additional study notes.
Goicoechea and Olivieri (1999b), calibration and test files bundled in
extra_docs/pls_data.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.